#
# spec file for package audacious
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define aud_plugin_ver_min 3.8
%define aud_plugin_ver_max 3.8.99
%define core_soname 4
%define qt_soname 1
%define gui_soname 4
%define tag_soname 3
%if 0%{?suse_version} >= 1320 || (0%{?sle_version} >= 120100 && 0%{?is_opensuse})
%bcond_without qt
%else
%bcond_with qt
%endif
%bcond_without gtk
Name:           audacious
Version:        3.8.2
Release:        1.1
Summary:        Advanced audio player
License:        BSD-2-Clause
Group:          Productivity/Multimedia/Sound/Players
Url:            http://audacious-media-player.org/
Source:         http://distfiles.audacious-media-player.org/%{name}-%{version}-gtk3.tar.bz2
# PATCH-FIX-UPSTREAM audacious-no-inode-directory-mimetype.patch i@marguerite.su -- Don't open directories with Audacious.
Patch:		audacious-no-inode-directory-mimetype.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++ >= 4.5
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1) >= 1.0.2
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.88
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.32
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.32
BuildRequires:  pkgconfig(libguess) >= 1.2
Requires:       %{name}-plugins%{?_isa} <= %{aud_plugin_ver_max}
Requires:       %{name}-plugins%{?_isa} >= %{aud_plugin_ver_min}
Recommends:     %{name}-lang
Recommends:     %{name}-plugins-extra >= %{aud_plugin_ver_min}
%if %{with gtk}
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4
%endif
%if %{with qt}
BuildRequires:  pkgconfig(Qt5Core) >= 5.2
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2
%endif

%description
Audacious is an advanced audio player. It is free, lightweight,
based on GTK+, runs on GNU/Linux and many other UNIX-like platforms,
and is focused on audio quality and supporting a wide range of
audio codecs. It still features an alternative skinned user
interface (based on Winamp 2.x skins).
Historically, it started as a fork of a fork of XMMS.

%lang_package

%package -n libaudcore%{core_soname}
Summary:        Library from the Audacious
Group:          System/Libraries
Provides:       libaudcore%{?_isa} = %{version}

%description -n libaudcore%{core_soname}
Library from the Audacious audio player.

%if %{with qt}
%package -n libaudqt%{qt_soname}
Summary:        Library from the Audacious
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudqt%{qt_soname}
Library from the Audacious audio player.
%endif

%if %{with gtk}
%package -n libaudgui%{gui_soname}
Summary:        Library from the Audacious
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudgui%{gui_soname}
Library from the Audacious audio player.
%endif

%package -n libaudtag%{tag_soname}
Summary:        Library from the Audacious
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudtag%{tag_soname}
Library from the Audacious audio player.

%package devel
Summary:        Development files for Audacious
Group:          Development/Libraries/C and C++
Requires:       libaudcore%{core_soname} = %{version}
Requires:       libaudtag%{tag_soname} = %{version}
%if %{with qt}
Requires:       libaudqt%{qt_soname} = %{version}
%endif
%if %{with gtk}
Requires:       libaudgui%{gui_soname} = %{version}
%endif

%description devel
Development files for Audacious audio player.

%prep
%setup -q -n %{name}-%{version}-gtk3
%patch -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
%if %{with qt}
  --enable-qt     \
%else
  --disable-qt    \
%endif
%if %{with gtk}
  --enable-gtk    \
%else
  --disable-gtk   \
%endif
  --disable-rpath
make %{?_smp_mflags} V=1

%install
%make_install
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
install -Dpm 0644 contrib/%{name}.appdata.xml %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml
%else
install -Dpm 0644 contrib/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%endif
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n libaudcore%{core_soname} -p /sbin/ldconfig

%postun -n libaudcore%{core_soname} -p /sbin/ldconfig

%if %{with qt}
%post -n libaudqt%{qt_soname} -p /sbin/ldconfig

%postun -n libaudqt%{qt_soname} -p /sbin/ldconfig
%endif

%if %{with gtk}
%post -n libaudgui%{gui_soname} -p /sbin/ldconfig

%postun -n libaudgui%{gui_soname} -p /sbin/ldconfig
%endif

%post -n libaudtag%{tag_soname} -p /sbin/ldconfig

%postun -n libaudtag%{tag_soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_bindir}/%{name}
%{_bindir}/audtool
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%else
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%endif
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_mandir}/man?/audtool.?%{?ext_man}

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n libaudcore%{core_soname}
%defattr(-,root,root)
%{_libdir}/libaudcore.so.%{core_soname}*

%if %{with qt}
%files -n libaudqt%{qt_soname}
%defattr(-,root,root)
%{_libdir}/libaudqt.so.%{qt_soname}*
%endif

%if %{with gtk}
%files -n libaudgui%{gui_soname}
%defattr(-,root,root)
%{_libdir}/libaudgui.so.%{gui_soname}*
%endif

%files -n libaudtag%{tag_soname}
%defattr(-,root,root)
%{_libdir}/libaudtag.so.%{tag_soname}*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_includedir}/libaudcore/
%{_libdir}/libaudcore.so
%if %{with qt}
%{_includedir}/libaudqt/
%{_libdir}/libaudqt.so
%endif
%if %{with gtk}
%{_includedir}/libaudgui/
%{_libdir}/libaudgui.so
%endif
%{_libdir}/libaudtag.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Jan 26 2017 sor.alexei@meowr.ru
- Update to version 3.8.2:
  * No changelog available.
* Wed Dec  7 2016 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * No changelog available.
- Rebase audacious-no-inode-directory-mimetype.patch
* Fri Sep 23 2016 sor.alexei@meowr.ru
- Update to version 3.8:
  * No changelog available.
- Rebase audacious-no-inode-directory-mimetype.patch
- Install the appstream file to /usr/share/metainfo/ instead of
  /usr/share/appdata/ on openSUSE Leap 42.2 and newer.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to 3.7.2.
* Fri Mar 25 2016 i@marguerite.su
- fix boo#972690: audacious is used to open directory
- add patch: audacious-no-inode-directory-mimetype.patch
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 3.7.1.
* Fri Nov 13 2015 aloisio@gmx.com
- Fixes audacious-plugins build on 13.1
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 3.7.
- Enable Qt UI.
* Fri Aug 21 2015 sor.alexei@meowr.ru
- Work with Audacious plugin versions instead of ABI versions to
  simplify things a lot.
* Mon Jun  1 2015 sor.alexei@meowr.ru
- Update to 3.6.2.
* Sat Apr  4 2015 sor.alexei@meowr.ru
- Update to 3.6.1.
* Sun Mar  1 2015 sor.alexei@meowr.ru
- Update to 3.6.
* Sun Dec 28 2014 sor.alexei@meowr.ru
- Update to 3.5.2.
- Spec cleanup.
* Tue Dec 17 2013 reddwarf@opensuse.org
- Update to 3.4.2
* Fri Mar 29 2013 fisiu@opensuse.org
- Update to 3.3.4:
  * Ported from gtk2 to gtk3
  * Save current track position
  * Improved search feature
  * Many bug fixes
* Sun Aug 19 2012 seife+obs@b1-systems.com
- update to current version 3.2.4
- removed no longer necessary -lgmodule-2.0 hack
* Tue May 22 2012 seife+obs@b1-systems.com
- fix build on > 12.1 by adding -lgmodule-2.0 to LIBS
* Fri Dec  9 2011 detlef@links2linux.de
- new upstream version <3.1.1>
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- update to 3.1
* Sun Nov  6 2011 detlef@links2linux.de
- new upstream version <3.0.3>
* Sun Aug 28 2011 detlef@links2linux.de
- new upstream version <3.0.2>
* Sat Aug 13 2011 detlef@links2linux.de
- new upstream version <3.0.1>
* Sat Jul  2 2011 detlef@links2linux.de
- new upstream version <2.5.3>
* Thu Jun 23 2011 detlef@links2linux.de
- new upstream version <2.5.2>
* Sat May 21 2011 detlef@links2linux.de
- new upstream version <2.5.1>
* Sun Apr 17 2011 detlef@links2linux.de
- new upstream version <2.5.0>
* Wed Feb 23 2011 detlef@links2linux.de
- new upstream version <2.4.4>
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <2.4.3>
* Wed Dec  8 2010 detlef@links2linux.de
- new upstream version <2.4.2>
* Fri Aug 27 2010 detlef@links2linux.de
- enable libguess support
* Wed Aug 25 2010 detlef@links2linux.de
- new upstream version <2.4-rc3>
* Fri Apr  9 2010 detlef@links2linux.de
- new upstream version <2.3>
* Wed Nov 25 2009 detlef@links2linux.de
- new upstream version <2.2>
* Wed Jul  8 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.1>
* Fri Jun  5 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.0.1>
* Tue Jul 22 2008 guru@unixtech.be
- added InitialPreference to action_audacious.desktop as it is
  associated with directories, in order to avoid it being the
  default action on directories
- added patch to fix specifying files on the command-line when
  audacious isn't already running:
  http://bugzilla.atheme.org/show_bug.cgi?id=48
* Sun Jul 20 2008 detlef@links2linux.de
- require audacious-plugins instead of audacious-plugins-option
  package managers are stupid ;)
* Thu Jul 10 2008 guru@unixtech.be
- require audacious-plugins-option instead of audacious-plugins
* Sun Jul  6 2008 guru@unixtech.be
- split shared libraries into its own -libs subpackage to avoid the
  chicken/egg problem when building audacious and audacious-plugins
  (as they both require each other), with audacious now requiring
  audacious-libs
- minor spec file cleanups
- added Provides for shlibs, openSUSE Shared Library Policy compliant
- more explicit filenames in files sections
- better Summary
- added glib backport patch to build on openSUSE 10.2
* Mon May 26 2008 detlef@links2linux.de
- new upstream version <1.5.1>
* Tue Apr 22 2008 detlef@links2linux.de
- fix Requires for devel
* Sun Mar 30 2008 detlef@links2linux.de
- disable ss2 for ix86, some old cpus doesn't support sse2
* Sat Mar 15 2008 detlef@links2linux.de
- new upstream version <1.5.0>
* Mon Feb 18 2008 detlef@links2linux.de
- rebuild with new libmcs-0.7
* Fri Feb  1 2008 detlef@links2linux.de
- new upstream version <1.4.6>
* Sat Dec 29 2007 detlef@links2linux.de
- new upstream version <1.4.5>
* Sat Dec 22 2007 detlef@links2linux.de
- rebuild for new libmcs and libmowgli
* Sat Dec  8 2007 detlef@links2linux.de
- add servicemenu for konqueror and dolphin
* Mon Dec  3 2007 detlef@links2linux.de
- new upstream version <1.4.4>
* Sat Dec  1 2007 detlef@links2linux.de
- new upstream version <1.4.3>
* Mon Nov 19 2007 detlef@links2linux.de
- new upstream release <1.4.1>
* Tue Nov  6 2007 detlef@links2linux.de
- new upstream release <1.4.0>
* Mon Nov  5 2007 detlef@links2linux.de
- switch to 1.4 on PackMan
- Audacious 1.4 is now complete, and is now recommended over 1.3
* Fri Nov  2 2007 detlef@links2linux.de
- new upstream release <1.4.0-rc1>
* Mon Oct 29 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta4>
* Fri Oct 19 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta2>
* Mon Oct 15 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta1>
* Thu Sep 20 2007 detlef@links2linux.de
- add xchat-plugin
* Thu Sep 13 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr4>
* Sun Sep  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr3>
* Thu Aug  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr2>
- fix BuildRequires -> add dbus-support
* Mon Jul 23 2007 detlef@links2linux.de
- initial build <1.4.0-dr1>
